@@ -19,9 +19,9 @@
 
 #include "itiphandlertest.h"
 #include "helper.h"
-#include "../mailclient_p.h"
-#include "../fetchjobcalendar.h"
-#include "../utils_p.h"
+#include "mailclient_p.h"
+#include "fetchjobcalendar.h"
+#include "utils_p.h"
 
 #include <kcalcore/icalformat.h>
 #include <kcalcore/attendee.h>
@@ -30,7 +30,7 @@
 #include <collectionfetchscope.h>
 #include <itemfetchscope.h>
 #include <qtest_akonadi.h>
-#include <mailtransport/messagequeuejob.h>
+#include <mailtransportakonadi/messagequeuejob.h>
 
 #include <kcalcore/event.h>
 
@@ -51,12 +51,12 @@ static const char *s_outEmail2 = "identity2@kde.org";
 class FakeMessageQueueJob : public MailTransport::MessageQueueJob
 {
 public:
-    explicit FakeMessageQueueJob(QObject *parent = Q_NULLPTR)
+    explicit FakeMessageQueueJob(QObject *parent = nullptr)
         : MailTransport::MessageQueueJob(parent)
     {
     }
 
-    virtual void start()
+    void start() Q_DECL_OVERRIDE
     {
         UnitTestResult unitTestResult;
         unitTestResult.message     = message();
@@ -81,12 +81,12 @@ UnitTestResult::List FakeMessageQueueJob::sUnitTestResults;
 class FakeITIPHandlerComponentFactory : public ITIPHandlerComponentFactory
 {
 public:
-    FakeITIPHandlerComponentFactory(QObject *parent = Q_NULLPTR)
+    FakeITIPHandlerComponentFactory(QObject *parent = nullptr)
         : ITIPHandlerComponentFactory(parent)
     {
     }
 
-    virtual MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = 0)
+    MailTransport::MessageQueueJob *createMessageQueueJob(const KCalCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) Q_DECL_OVERRIDE
     {
         Q_UNUSED(incidence);
         Q_UNUSED(identity);
@@ -97,6 +97,8 @@ public:
 void ITIPHandlerTest::initTestCase()
 {
     AkonadiTest::checkTestIsIsolated();
+    extern AKONADI_CALENDAR_TESTS_EXPORT bool akonadi_calendar_running_unittests;
+    akonadi_calendar_running_unittests = true;
     m_pendingItipMessageSignal = 0;
     m_pendingIncidenceChangerSignal = 0;
     m_itipHandler = 0;
@@ -634,7 +636,7 @@ void ITIPHandlerTest::createITIPHandler()
 
 QString ITIPHandlerTest::icalData(const QString &data_filename)
 {
-    QString absolutePath = QLatin1String(ITIP_DATA_DIR) + QLatin1Char('/') + data_filename;
+    QString absolutePath = QFINDTESTDATA(QStringLiteral("itip_data/") + data_filename);
     return QString::fromLatin1(readFile(absolutePath));
 }
 
@@ -702,7 +704,7 @@ void ITIPHandlerTest::onCreateFinished(int changeId, const Item &item,
     QCOMPARE(resultCode, IncidenceChanger::ResultCodeSuccess);
 }
 
-void ITIPHandlerTest::onDeleteFinished(int changeId, const QVector<Entity::Id> &deletedIds,
+void ITIPHandlerTest::onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &deletedIds,
                                        IncidenceChanger::ResultCode resultCode,
                                        const QString &errorString)
 {
@@ -735,4 +737,4 @@ void ITIPHandlerTest::onModifyFinished(int changeId, const Item &item,
              : IncidenceChanger::ResultCodeSuccess);
 }
 
-QTEST_AKONADIMAIN(ITIPHandlerTest, GUI)
+QTEST_AKONADIMAIN(ITIPHandlerTest)
