@@ -135,7 +135,7 @@ QUrl FbCheckerJob::validUrl() const
 /// FreeBusyManagerPrivate::FreeBusyProviderRequest
 
 FreeBusyManagerPrivate::FreeBusyProviderRequest::FreeBusyProviderRequest(const QString &provider)
-    : mRequestStatus(NotStarted), mInterface(Q_NULLPTR)
+    : mRequestStatus(NotStarted), mInterface(nullptr)
 {
     mInterface =
         QSharedPointer<QDBusInterface>(
@@ -148,7 +148,7 @@ FreeBusyManagerPrivate::FreeBusyProviderRequest::FreeBusyProviderRequest(const Q
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(
     const QString &start, const QString &end)
-    : mHandlersCount(0), mResultingFreeBusy(Q_NULLPTR)
+    : mHandlersCount(0), mResultingFreeBusy(nullptr)
 {
     KDateTime startDate, endDate;
 
@@ -175,7 +175,7 @@ FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequest
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(
     const KDateTime &start, const KDateTime &end)
-    : mHandlersCount(0), mResultingFreeBusy(Q_NULLPTR)
+    : mHandlersCount(0), mResultingFreeBusy(nullptr)
 {
     mStartTime = start.toString();
     mEndTime = end.toString();
@@ -190,7 +190,7 @@ FreeBusyManagerPrivate::FreeBusyManagerPrivate(FreeBusyManager *q)
       mTimerID(0),
       mUploadingFreeBusy(false),
       mBrokenUrl(false),
-      mParentWidgetForRetrieval(Q_NULLPTR)
+      mParentWidgetForRetrieval(nullptr)
 {
     connect(this, &FreeBusyManagerPrivate::freeBusyUrlRetrieved,
             this, &FreeBusyManagerPrivate::finishProcessRetrieveQueue);
@@ -254,7 +254,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
     QString url = group.readEntry(QStringLiteral("url"));
 
     const KContacts::Addressee::List contacts = job->contacts();
-    foreach (const KContacts::Addressee &contact, contacts) {
+    for (const KContacts::Addressee &contact : contacts) {
         const QString pref = contact.preferredEmail();
         if (!pref.isEmpty() && pref != email) {
             group = cfg.group(pref);
@@ -455,7 +455,7 @@ void FreeBusyManagerPrivate::processFreeBusyUploadResult(KJob *_job)
     KIO::FileCopyJob *job = static_cast<KIO::FileCopyJob *>(_job);
     if (job->error()) {
         KMessageBox::sorry(
-            0,
+            nullptr,
             i18n("<qt><p>The software could not upload your free/busy list to "
                  "the URL '%1'. There might be a problem with the access "
                  "rights, or you specified an incorrect URL. The system said: "
@@ -571,8 +571,8 @@ void FreeBusyManagerPrivate::uploadFreeBusy()
 QStringList FreeBusyManagerPrivate::getFreeBusyProviders() const
 {
     QStringList providers;
-    Akonadi::AgentInstance::List agents = Akonadi::AgentManager::self()->instances();
-    foreach (const Akonadi::AgentInstance &agent, agents) {
+    const Akonadi::AgentInstance::List agents = Akonadi::AgentManager::self()->instances();
+    for (const Akonadi::AgentInstance &agent : agents) {
         if (agent.type().capabilities().contains(QStringLiteral("FreeBusyProvider"))) {
             providers << agent.identifier();
         }
@@ -587,7 +587,7 @@ void FreeBusyManagerPrivate::queryFreeBusyProviders(const QStringList &providers
         mProvidersRequestsByEmail[email] = FreeBusyProvidersRequestsQueue();
     }
 
-    foreach (const QString &provider, providers) {
+    for (const QString &provider : providers) {
         FreeBusyProviderRequest request(provider);
 
         connect(request.mInterface.data(), SIGNAL(handlesFreeBusy(QString,bool)),
@@ -926,7 +926,7 @@ void FreeBusyManager::mailFreeBusy(int daysToPublish, QWidget *parentWidget)
     QPointer<PublishDialog> publishdlg = new PublishDialog();
     if (publishdlg->exec() == QDialog::Accepted) {
         // Send the mail
-        MailScheduler *scheduler = new MailScheduler(/*factory=*/Q_NULLPTR, this);
+        MailScheduler *scheduler = new MailScheduler(/*factory=*/nullptr, this);
         connect(scheduler, &Scheduler::transactionFinished
                 , d, &FreeBusyManagerPrivate::processMailSchedulerResult);
         d->mParentWidgetForMailling = parentWidget;
