@@ -37,11 +37,8 @@
 using namespace Akonadi;
 using namespace KCalCore;
 
-#ifdef PLEASE_TEST_INVITATIONS
-# define RUNNING_UNIT_TESTS true
-#else
-# define RUNNING_UNIT_TESTS false
-#endif
+AKONADI_CALENDAR_TESTS_EXPORT bool akonadi_calendar_running_unittests = false;
+
 
 static ITIPHandlerDialogDelegate::Action actionFromStatus(ITIPHandlerHelper::SendResult result)
 {
@@ -133,7 +130,7 @@ IncidenceChanger::Private::Private(bool enableHistory, ITIPHandlerComponentFacto
     mLatestChangeId = 0;
     mShowDialogsOnError = true;
     mFactory = factory ? factory : new ITIPHandlerComponentFactory(this);
-    mHistory = enableHistory ? new History(this) : Q_NULLPTR;
+    mHistory = enableHistory ? new History(this) : nullptr;
     mUseHistory = enableHistory;
     mDestinationPolicy = DestinationPolicyDefault;
     mRespectsCollectionRights = false;
@@ -141,7 +138,7 @@ IncidenceChanger::Private::Private(bool enableHistory, ITIPHandlerComponentFacto
     mLatestAtomicOperationId = 0;
     mBatchOperationInProgress = false;
     mAutoAdjustRecurrence = true;
-    m_collectionFetchJob = Q_NULLPTR;
+    m_collectionFetchJob = nullptr;
     m_invitationPolicy = InvitationPolicyAsk;
 
     qRegisterMetaType<QVector<Akonadi::Item::Id> >("QVector<Akonadi::Item::Id>");
@@ -194,7 +191,7 @@ Akonadi::Job *IncidenceChanger::Private::parentJob(const Change::Ptr &change) co
 {
     return (mBatchOperationInProgress && !change->queuedModification) ?
            mAtomicOperations[mLatestAtomicOperationId]->transaction()
-           : Q_NULLPTR;
+           : nullptr;
 }
 
 void IncidenceChanger::Private::queueModification(const Change::Ptr &change)
@@ -336,7 +333,7 @@ void IncidenceChanger::Private::handleDeleteJobResult(KJob *job)
     QSharedPointer<DeletionChange> deletionChange = change.staticCast<DeletionChange>();
 
     deletionChange->mItemIds.reserve(deletionChange->mItemIds.count() + items.count());
-    foreach (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         deletionChange->mItemIds.append(item.id());
     }
     QString description;
@@ -551,7 +548,7 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
                 return;
             }
 
-            if (RUNNING_UNIT_TESTS && !weAreOrganizer(newIncidence)) {
+            if (akonadi_calendar_running_unittests && !weAreOrganizer(newIncidence)) {
                 // This is a bit of a workaround when running tests. I don't want to show the
                 // "You're not organizer, do you want to modify event?" dialog in unit-tests, but want
                 // to emulate a "yes" and a "no" press.
@@ -618,7 +615,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
         }
         case IncidenceChanger::ChangeTypeDelete: {
             handler->deleteLater();
-            handler = Q_NULLPTR;
+            handler = nullptr;
             Q_ASSERT(!change->originalItems.isEmpty());
             foreach (const Akonadi::Item &item, change->originalItems) {
                 Q_ASSERT(item.hasPayload());
@@ -686,13 +683,13 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
         }
         default:
             handler->deleteLater();
-            handler = Q_NULLPTR;
+            handler = nullptr;
             Q_ASSERT(false);
             change->emitUserDialogClosedAfterChange(ITIPHandlerHelper::ResultCanceled);
             return;
         }
         handler->deleteLater();
-        handler  = Q_NULLPTR;
+        handler  = nullptr;
         change->emitUserDialogClosedAfterChange(ITIPHandlerHelper::ResultSuccess);
     } else {
         change->emitUserDialogClosedAfterChange(ITIPHandlerHelper::ResultSuccess);
@@ -714,7 +711,7 @@ bool IncidenceChanger::Private::myAttendeeStatusChanged(const Incidence::Ptr &ne
 
 IncidenceChanger::IncidenceChanger(QObject *parent)
     : QObject(parent)
-    , d(new Private(/**history=*/true, /*factory=*/Q_NULLPTR, this))
+    , d(new Private(/**history=*/true, /*factory=*/nullptr, this))
 {
 }
 
@@ -726,7 +723,7 @@ IncidenceChanger::IncidenceChanger(ITIPHandlerComponentFactory *factory, QObject
 
 IncidenceChanger::IncidenceChanger(bool enableHistory, QObject *parent)
     : QObject(parent)
-    , d(new Private(enableHistory, /*factory=*/Q_NULLPTR, this))
+    , d(new Private(enableHistory, /*factory=*/nullptr, this))
 {
 }
 
@@ -788,7 +785,7 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
         return -1;
     }
 
-    foreach (const Item &item, items) {
+    for (const Item &item : items) {
         if (!item.isValid()) {
             qCritical() << "Items must be valid!";
             d->cancelTransaction();
@@ -800,7 +797,7 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
     const int changeId = ++d->mLatestChangeId;
     const Change::Ptr change(new DeletionChange(this, changeId, atomicOperationId, parent));
 
-    foreach (const Item &item, items) {
+    for (const Item &item : items) {
         if (!d->hasRights(item.parentCollection(), ChangeTypeDelete)) {
             qCWarning(AKONADICALENDAR_LOG) << "Item " << item.id() << " can't be deleted due to ACL restrictions";
             const QString errorString = d->showErrorDialog(ResultCodePermissions, parent);
@@ -978,7 +975,7 @@ void IncidenceChanger::Private::performModification(const Change::Ptr &change)
     const bool hasAtomicOperationId = atomicOperationId != 0;
     if (hasAtomicOperationId &&
             mAtomicOperations[atomicOperationId]->rolledback()) {
-        const QString errorMessage = showErrorDialog(ResultCodeRolledback, Q_NULLPTR);
+        const QString errorMessage = showErrorDialog(ResultCodeRolledback, nullptr);
         qCritical() << errorMessage;
         emitModifyFinished(q, changeId, newItem, ResultCodeRolledback, errorMessage);
         return;
@@ -1402,7 +1399,7 @@ AtomicOperation::AtomicOperation(IncidenceChanger::Private *icp,
     , m_numCompletedChanges(0)
     , m_transactionCompleted(false)
     , m_wasRolledback(false)
-    , m_transaction(Q_NULLPTR)
+    , m_transaction(nullptr)
     , m_incidenceChangerPrivate(icp)
 
 {
